====================================
``psyclone.psyir.nodes.omp_clauses``
====================================

.. automodule:: psyclone.psyir.nodes.omp_clauses

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.omp_clauses
